=======================
 Invenio-Assets v1.0.0
=======================

Invenio-Assets v1.0.0 was released on November 16, 2015.

About
-----

Media assets management for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-assets==1.0.0

Documentation
-------------

   http://pythonhosted.org/invenio-assets/

Happy hacking and thanks for flying Invenio-Assets.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-assets
|   URL: http://invenio-software.org
